How to setup an openstack with multi region support with single keystone - Ask OpenStack: Q&A Site for OpenStack Users and Developers
Description: I want to setup an openstack with multi region support using single keystone instance, each region will have a kvm host with nova, someone know how to do that?
Keywords: ,Ask, OpenStack,forum,community,cloud,iaas

First time here? Check out the FAQ!

English ▼
Hi there! Please sign in tags users badges help

| ALL UNANSWERED |  | Ask Your Question

12

# How to setup an openstack with multi region support with single keystone

- keystone
- multiregion

asked 2013-03-20 16:29:40 -0600

volmar-junior
123 ●2 ●4 ●4

I want to setup an openstack with multi region support using single keystone instance, each region will have a kvm host with nova, someone know how to do that?

edit retag flag offensive close merge delete

## Comments

the document mentioned above can't be accessed, can you paste your document content here ?

gws ( 2014-04-23 20:59:08 -0600 )edit
add a comment

## 2 answers

Sort by » oldest newest most voted
14

answered 2013-03-20 18:51:20 -0600

jtopjian
655 ●2 ●5 ●16 http://terrarum.net/

updated 2013-03-24 14:15:07 -0600

smaffulli
6898 ●36 ●67 ●100 http://maffulli.net/

This is possible to do by playing around with the Keystone `endpoint` table. The only problematic area is that it doesn't work in Horizon without making some changes.

This document describes the changes needed to get Horizon to work. I have been meaning to turn this into a proper blog post or article so it's actually searchable on the web. See the section on "Central Authentication".

There's a Blueprint that I have been meaning to work on that would officially incorporate these changes.

Besides regions, there's also Cells. Although fundamentally different than Regions, Cells can partition your OpenStack cloud into separate areas while still sharing services between areas.

edit flag offensive delete link more

## Comments

Nice work. How much of this work has been merged into the codebase or at least been used as the basis for blueprints?

jesse-pretorius ( 2013-03-22 05:41:33 -0600 )edit

Nice! this will help my investigation, we are also interested in this blueprint implementation, maybe we can do a collaborative work, did you already talked with Gabriel Hurley about that?

volmar-junior ( 2013-03-25 08:55:29 -0600 )edit

I have, yes. The blueprint was created from the result of conversation with him. I hope find time to work on it in the coming months. Two reasons why I haven't yet are just out of laziness and ensuring work wouldn't be duplicated wrt Cells.

jtopjian ( 2013-03-25 09:16:25 -0600 )edit

Hi Topjian!!! Is there anything that we can do to help you in this blueprint? I mean, help in the blueprint spec, tests and commit process? We'd be glad to help you. :-)

eisotton ( 2013-03-26 11:55:24 -0600 )edit

I would suggest you to discuss new features on the Development mailing list https://wiki.openstack.org/wiki/MailingLists. Also, have you suggested this as a topic for the OpenStack Design Summit http://summit.openstack.org ?

smaffulli ( 2013-03-26 12:07:49 -0600 )edit
add a comment see more comments
2

answered 2014-12-11 13:56:22 -0600

smaffulli
6898 ●36 ●67 ●100 http://maffulli.net/

Keystone has made lots of progress to enable federation. A good starting point is the [official documentation[(http://docs.openstack.org/developer/keystone/configure_federation.html).

edit flag offensive delete link more
add a comment

## Your Answer

Please start posting anonymously - your entry will be published after you log in or create a new account.

Add Answer

[hide preview]

# Get to know Ask OpenStack

Resources for moderators

## Question Tools

3 followers

## Stats

Asked: 2013-03-20 16:29:40 -0600

Seen: 6,293 times

Last updated: Dec 11 '14

## Related questions

Installing Openstack

Compute(nova) endpoint not listening

Dashboard throwing error on login [closed]

Tenent and User Behavior

Unexpected error while requesting for authentication token

Code question on domain config reloads

Identity api 3.6

The keystone CLI is deprecated in favor of python-openstackclien

Swift-keystone integration: Getting HTTP/1.1 401 Unauthorized error [closed]

Devstack installation failure

( 2016-11-08 08:57:50 -0600 )edit
none